package App::Mver;

our $VERSION = '0.03';

# vim: ft=perl

__END__

=encoding utf8

=head1 NAME

App::Mver - just print modules' $VERSION

=head1 DESCRIPTION

For those, who are sick of

    perl -MLong::Module::Name -le'print Long::Module::Name->VERSION'

=head1 SYNOPSIS

    mver Module::Name

    mver Module-Name

=head1 AUTHOR

Алексей Суриков E<lt>ksuri@cpan.orgE<gt>

=head1 LICENSE

This program is free software, you can redistribute it under the same terms as Perl itself.
